export enum BorderStyleTypes {
    NONE,
    THIN,
    HAIR,
    DOTTED,
    DASHED,
    DASH_DOT,
    DASH_DOT_DOT,
    DOUBLE,
    MEDIUM,
    MEDIUM_DASHED,
    MEDIUM_DASHDOT,
    MEDIUM_DASH_DOT_DOT,
    SLANT_DASH_DOT,
    THICK,
}

export enum ThemeColor{
    TEXT,
    BACKGROUND,
    ACCENT1,
    ACCENT2,
    ACCENT3,
    ACCENT4,
    ACCENT5,
    ACCENT6,
    LINK,
}

export enum TextDecoration {
    DASH,
    DASH_DOT_DOT_HEAVY,
    DASH_DOT_HEAVY,
    DASHED_HEAVY,
    DASH_LONG,
    DASH_LONG_HEAVY,
    DOT_DASH,
    DOT_DOT_DASH,
    DOTTED,
    DOTTED_HEAVY,
    DOUBLE,
    NONE,
    SINGLE,
    THICK,
    WAVE,
    WAVY_DOUBLE,
    WAVY_HEAVY,
    WORDS,
}

export interface IBorderStyleData {
    /**
     * color type
     */
    cl: IColorStyle;

    /**
     * border type
     */
    s: BorderStyleTypes;
}

export interface IBorderData {
    /**
     * top border
     */
    t: IBorderStyleData;

    /**
     * right border
     */
    r: IBorderStyleData;

    /**
     * bottom border
     */
    b: IBorderStyleData;

    /**
     * left border
     */
    l: IBorderStyleData;
}

export interface IColorStyle {
    /**
     * rgb color
     */
    rgb: string;

    /**
     * theme color
     */
    th: ThemeColor;
}

export interface ITextRotation {
    /**
     * angle
     */
    a: number;

    /**
     * vertical
     * true : 1
     * false : 0
     */
    v?: number;
}

export interface ITextDecoration {
    /**
     * colorType
     */
    cl: IColorStyle;

    /**
     * controller display textDecoration
     */
    s: boolean;

    /**
     * text decoration type
     */
    t: TextDecoration;
}

export class CellStyle {
    /**
     * fontFamily
     */
    ff: string;

    /**
     * fontSize
     */
    fs: number;

    /**
     * italic
     * 0: false
     * 1: true
     */
    it: number;

    /**
     * bold
     * 0: false
     * 1: true
     */
    bl: number;

    /**
     * underline
     */
    ul: ITextDecoration;

    /**
     * strikethrough
     */
    st: ITextDecoration;

    /**
     * overline
     */
    ol: ITextDecoration;

    /**
     * background
     */
    bg: IColorStyle;

    /**
     * border
     */
    bd: IBorderData;

    /**
     * foreground
     */
    cl: IColorStyle;
}